@@ -17,7 +17,7 @@ logger = logging.getLogger(__name__)
 
 CANKER_TOOL_MAP = {
     "canker-cc": "CC",
-    "canker-cxx": "CXX",
+    "canker-c++": "CXX",
     "canker-cpp": "CPP",
     "canker-ld": "LD",
     "canker-as": "AS",
@@ -28,7 +28,7 @@ TOOL_ENV_MAP = {
     "CXX": "c++",
     "CPP": "cpp",
     "LD": "ld",
-    "as": "as",
+    "AS": "as",
 }
 
 TOOL_ENV_WRAPPER_MAP = {
@@ -418,6 +418,12 @@ class CompilerTool(Tool, StdMixin, OptMixin):
         Returns:
             A `canker.enums.CompilerStage` value representing the stage that this tool is on
         """
+
+        # TODO(ww): Refactor this entire method. Both GCC and Clang can actually
+        # run multiple stages per invocation, e.g. `-x c foo.c -x c++ bar.cpp`,
+        # so we should model this as "stages" instead. This, in turn, will require
+        # us to reevaluate our output guesswork below.
+
         if len(self.args) == 0:
             return CompilerStage.Unknown
 
